package com.kym.service.admin;

import com.github.yulichang.base.MPJBaseService;
import com.kym.entity.admin.Activity;
import com.kym.entity.admin.queryParams.ActivityQueryParam;
import com.kym.entity.admin.vo.ActivityVo;
import com.kym.entity.common.PageBean;

import java.util.List;

/**
 * <p>
 * 服务类
 * </p>
 *
 * @author skyline
 * @since 2023-10-18
 */
public interface ActivityService extends MPJBaseService<Activity> {

    void createActivity(ActivityVo activityVo);

    PageBean<Activity> listActivity(ActivityQueryParam params);

    ActivityVo activityDetail(String params);

    void terminateActivity(String activityId);

    void handleRechargeActivity(long userId, int rechargeAmount);

    List<Activity> getAvailableCouponActivities();
}
